#
# spec file for package openstack-neutron-gbp
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%define component gbpservice

%if ! %{defined _rundir}
%define _rundir %{_localstatedir}/run
%endif

%define version_unconverted 5.1.0

Name:           openstack-neutron-gbp
Version:        5.1.0
Release:        4.1
Summary:        Openstack Group Based Policy
License:        Apache-2.0
Group:          System/Management
Url:            https://launchpad.net/group-based-policy
# NOTE(rhafer): source tarball generated from git checkout of
#   https://github.com/noironetworks/group-base-policy/
#   using python setup.py sdist
Source          https://github.com/noironetworks/group-based-policy/archive/%{version}.tar.gz
Patch1:         0001_alembic_migrations_enum_name.patch
BuildRequires:  crudini
BuildRequires:  fdupes
BuildRequires:  openstack-suse-macros
BuildRequires:  python-devel
BuildRequires:  python-pbr
BuildRequires:  python-Sphinx
BuildRequires:  python-oslosphinx
Requires:       python >= 2.6.8
# Requires:       python-neutron-gbp = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%py_requires
%else
BuildArch:      noarch
%endif
PreReq:         %fillup_prereq

%description
Group Based Policy (GBP) provides declarative abstractions for achieving
scalable intent-based infrastructure automation.
        
GBP complements the OpenStack networking model with the notion of policies
that can be applied between groups of network endpoints. As users look beyond
basic connectivity, richer network services with diverse implementations and
network properties are naturally expressed as policies. Examples include
service chaining, QoS, path properties, access control, etc.

%package -n     python-neutron-gbp
Summary:        OpenStack Group Based Policy - Python module
Group:          Development/Languages/Python
Requires:       python >= 2.6.8
Requires:       python-httplib2 >= 0.7.5
Requires:       python-pbr >= 1.6

%description -n python-neutron-gbp
This package contains the core Python module of Group Based Policy (GBP)

%package test
Summary:        OpenStack Group Based Policy - Testsuite
Group:          Development/Languages/Python
Requires:       %{name} = %{version}
Requires:       python-tempest-lib >= 0.8.0
Requires:       python-reno >= 0.1.1
Requires:       python-oslotest >= 1.10.0
Requires:       python-testresources >= 0.2.4
Requires:       python-os-testr >= 0.1.0
Requires:       python-cliff >= 1.14.0
Requires:       python-testscenarios >= 0.4
Requires:       python-testrepository >= 0.0.18
Requires:       python-fixtures >= 1.3.1
Requires:       python-WebTest >= 2.0
Requires:       python-python-subunit >= 0.0.18
Requires:       python-testtools >= 1.4.0
Requires:       python-requests-mock >= 0.6.0
Requires:       python-ddt >= 0.7.0
Requires:       python-mock >= 1.2

%description test
OpenStack Group Based Policy - Testsuite

%prep
%setup -q -n group-based-policy-%{version_unconverted}
%patch1 -p1
%openstack_cleanup_prep

%build
python setup.py build
python setup.py build_sphinx -b man
#tools/config/generate_sample.sh -p gbpservice

%install
python setup.py install --skip-build --prefix=%{_prefix} --root=%{buildroot} --install-data=/

# move configfiles into the probper location
install -d -m 755 %{buildroot}%{_sysconfdir}/neutron
install -d -m 755 %{buildroot}%{_sysconfdir}/neutron/group-based-policy
install -d -m 755 %{buildroot}%{_sysconfdir}/neutron/group-based-policy/policy.d
install -d -m 755 %{buildroot}%{_sysconfdir}/neutron/group-based-policy/drivers
install -d -m 755 %{buildroot}%{_sysconfdir}/neutron/servicechain
install -d -m 755 %{buildroot}%{_sysconfdir}/neutron/servicechain/plugins
install -d -m 755 %{buildroot}%{_sysconfdir}/neutron/servicechain/plugins/msc
mv %{buildroot}%{_sysconfdir}/group-based-policy/drivers/*.ini %{buildroot}%{_sysconfdir}/neutron/group-based-policy/drivers/
mv %{buildroot}%{_sysconfdir}/group-based-policy/grouppolicy.ini %{buildroot}%{_sysconfdir}/neutron/group-based-policy/
mv %{buildroot}%{_sysconfdir}/group-based-policy/policy.d/policy.json %{buildroot}%{_sysconfdir}/neutron/
mv %{buildroot}%{_sysconfdir}/servicechain/plugins/msc/servicechain.ini %{buildroot}%{_sysconfdir}/neutron/servicechain/plugins/msc/
mv %{buildroot}%{_sysconfdir}/servicechain/plugins/msc/simplechain.ini %{buildroot}%{_sysconfdir}/neutron/servicechain/plugins/msc/


### test subpackage
%openstack_test_package_install
%fdupes %{buildroot}%{_localstatedir}/lib/%{name}-test

### misc
%fdupes %{buildroot}%{python_sitelib}/%{component}
%fdupes %{buildroot}%{_bindir}

%files
%defattr(-,root,root,-)
%doc LICENSE README.rst
%dir %{_sysconfdir}/neutron
%dir %{_sysconfdir}/neutron/group-based-policy
%dir %{_sysconfdir}/neutron/group-based-policy/policy.d/
%dir %{_sysconfdir}/neutron/group-based-policy/drivers
%dir %{_sysconfdir}/neutron/servicechain
%dir %{_sysconfdir}/neutron/servicechain/plugins
%dir %{_sysconfdir}/neutron/servicechain/plugins/msc
%config(noreplace) %attr(0640, root, neutron) %{_sysconfdir}/neutron/group-based-policy/*.ini
%config(noreplace) %attr(0640, root, neutron) %{_sysconfdir}/neutron/group-based-policy/drivers/*.ini
%config(noreplace) %attr(0640, root, neutron) %{_sysconfdir}/neutron/servicechain/plugins/msc/servicechain.ini
%config(noreplace) %attr(0640, root, neutron) %{_sysconfdir}/neutron/servicechain/plugins/msc/simplechain.ini
%config(noreplace) %attr(0640, root, neutron) %{_sysconfdir}/nfp.ini
%config(noreplace) %attr(0640, root, neutron) %{_sysconfdir}/neutron/policy.json
%{_bindir}/gbp-db-manage
%{_bindir}/nfp
%{_bindir}/nfp_proxy


%files -n python-neutron-gbp
%defattr(-,root,root,-)
%doc LICENSE
%{python_sitelib}/%{component}/
%{python_sitelib}/group_based_policy-*.egg-info
# Part of test subpackage
%exclude %{python_sitelib}/%{component}/tests/

%files test
%defattr(-,root,root)
%{python_sitelib}/%{component}/tests/
%{_localstatedir}/lib/%{name}-test/

%changelog
* Thu Dec 14 2017 mmnelemane@suse.com
- Updated spec file correctly to include the gbp migration fixes
  - Removed patch to modify MANIFEST.in
  - included the migrations files before creating the dist package
  - Used only one patch to fix the Enum name error during
    migration: 0001_alembic_migrations_enum_name.patch
* Fri Dec  1 2017 mmnelemane@suse.com
- Fixed alembic db migrations with the following patches:
  * 0001_alembic_migrations_enum_name.patch
  * 0002_include_alembic_ini_and_versions.patch
* Fri Aug 25 2017 mmnelemane@suse.com
- Upgrade to 5.1.0 for APIC firmware 2.2.2
* Thu Jul 27 2017 mmnelemane@suse.com
- Updated to 4.4.0 for APIC firmware 2.3
* Thu Jun 15 2017 rhafer@suse.de
- Switch to proper sdist tarball
* Tue Nov  8 2016 mmnelemane@suse.com
- Reverted to Version 2015.2.7 to fix apic conflict
* Wed Nov  2 2016 cloud-devel@suse.de
- Update to version group-based-policy-2015.2.8.dev4:
  * [APIC-mapping] Fix intermittent UT failure
* Tue Nov  1 2016 cloud-devel@suse.de
- Update to version group-based-policy-2015.2.8.dev3:
  * [APIC-mapping] Copy over provider physical network
  2014.2rc1
* Fri Oct 21 2016 cloud-devel@suse.de
- Update to version group-based-policy-2015.2.8.dev2:
  * [apic-mapping] guard against null port-id on master PTs
* Thu Oct 20 2016 mlakat@suse.com
- Added nfp binaries and ini files to the spec file
* Thu Oct 20 2016 mlakat@suse.com
- Update to version group-based-policy-2015.2.8.dev1:
  * NFP - Fixes to support openstack installation
  2015.2.7
  * Sort multiple macs in port lookup
  * [apic] fix proxy_group migration default
  * [apic-mapping] Allowed VM Name extension for L3 Policy
  * [apic-mapping] Fix table name for segmentation table
  * [aim-mapping] Fix PT create error in auto-ptg
  * [NFP] - Fixed nfp-proxy startup
  * [apic-mapping] Segmentation Label extension for PT
  * [NFP] - Calculate interface netmask in nfp-proxy namespace
  * [APIC-mapping] Fix device_id of port when using VLAN network
  * [apic_mapping] cast nat_epg_tenant to string before RPC answer
  * [apic_mapping] APIC name usage error in Auto PTG
  * [apic-mapping] Automatic PTG per L2P
  * NFP -Added Cluster ID fix
  * NFP - Added APIC support and other fixes for V0 release installation
  * NFP - Fixed stale resources issue
  * NFP - Elimination of neutron-lib Package
  * ptg attribute for sc enforcement
  * [apic-mapping] notify all ports in a cluster
  * Fix tox env to facilitate generation of tarball
  * NFP - Core UT fix
  * Fix exception log due to access of incorrect thread attribute
  * NFP (contrib) - Build and Configure Changes of NFP
  * NFP (contrib) - Controller VM root login
  2015.2.6
  * Fix NFP service_plugin entrypoint
  * NFP (contrib) - Controller Image Build Scripts
  * NFP - ini files and entry points
  * NFP (contrib) - Devstack and Diskimage Create Scripts
  * NFP (contrib) - Service Plugins
  * NFP (contrib) - Service Drivers
  * NFP (contrib) - Service Agents
  * NFP (contrib) - Configurator
  * NFP (contrib) - Over the Cloud Network Function Controller
  * NFP - Pecan controller enhancements to support configuration patches
  * NFP - Enhancements and fixes to master NFP
  * Fixes Unauthorized failure in liberty
  * Splitting NFP integration tests - part 2
  * Splitting NFP integration tests into new job
  * [apic-mapping] Explicit end of the chain for ptgs
  * Fix for cross tenancy issue with neutron
  * Added fix for node update failure
  * Fixes for multiple notifications in node drivers
  * NFP - Reference Service Implementation
  * NFP - Base Configurator Reference Implementation
  * NFP - Node Driver
  * NFP - Heat driver implementation
  * NFP - Orchestration driver
  * NFP - Device Orchestrator implementation
  * NFP - Base mode Service Orchestrator
  * NFP - Service Orchestrator module
  * NFP - Client utilities for OpenStack services
  * NFP - DB Framework and DB Model Implementation
  * NFP - Multi process framework implementation
  * Fix for service target creation in chain
  * Fix branch-name in refernce local.conf and README files
  * NFP (contrib) - Config Orchestrator
  * Use upper-constraints for requirements' versions
  * NFP - Devstack and Diskimage Create Scripts
  * Add support for L3P lookup using router ID
  2015.2.5
  2014.2.rc1
* Sun Jul 10 2016 cloud-devel@suse.de
- Update to version group-based-policy-2015.2.5.dev26:
  * [apic_mapping] Don't create NatEPG/NatBD when EdgeNat is on
* Wed Jun 29 2016 cloud-devel@suse.de
- Update to version group-based-policy-2015.2.5.dev25:
  * [APIC mapping] Support per-tenant NAT EPGs
* Mon Jun 27 2016 cloud-devel@suse.de
- Update to version group-based-policy-2015.2.5.dev24:
  * opflex 1.1 compliance
  * [apic_mapping] Fix bugs while setting auto-l3out for BDs
  2015.2.4
* Sat Jun 25 2016 cloud-devel@suse.de
- Update to version group-based-policy-2014.2.10.dev21:
  * [apic]Fix expected req body for l3out UTs
  * Status attributes for GBP resources
* Fri Jun 24 2016 cloud-devel@suse.de
- Update to version group-based-policy-2014.2.10.dev18:
  * Propagate allowed address pairs to head of the chain
* Thu Jun 23 2016 cloud-devel@suse.de
- Update to version group-based-policy-2014.2.10.dev17:
  * [apic_mapping] Use the tenant name instead of ID while cloning l3out
* Wed Jun 22 2016 cloud-devel@suse.de
- Update to version group-based-policy-2014.2.10.dev16:
  * Better quota enforcement for GBP resources
* Sat Jun 18 2016 cloud-devel@suse.de
- Update to version group-based-policy-2014.2.10.dev15:
  * [APIC mapping] Associate BDs to L3Outs even when NAT is disabled
  * Add support for per-VRF SNAT IP allocation
* Fri Jun 17 2016 cloud-devel@suse.de
- Update to version group-based-policy-2014.2.10.dev12:
  * [APIC-mapping] Update dependencies on APIC libraries
  * Use the proper pre_existing method from apic mapper
* Thu Jun 16 2016 cloud-devel@suse.de
- Update to version group-based-policy-2014.2.10.dev9:
  * Fix unnamed contraints removal for postgresql
  * Fix gate job devstack conf disabling heat
* Sat Jun 11 2016 cloud-devel@suse.de
- Update to version group-based-policy-2014.2.10.dev7:
  * Fix Port Group name construction
  * Also allow SVI while cloning the Auto-l3out
* Fri Jun 10 2016 cloud-devel@suse.de
- Update to version group-based-policy-2014.2.10.dev5:
  * use the scoped name for the VRF also while cloning l3out
* Sun Jun  5 2016 cloud-devel@suse.de
- Update to version group-based-policy-2014.2.10.dev4:
  * Fix service chain instance deletion on PRS update
* Fri Apr 29 2016 rhafer@suse.de
- initial submission
